@@ -29,7 +29,7 @@ use strict;
 ######################################################################
 #### Configuration Section
 
-our $VERSION = '1.056';
+our $VERSION = '1.060';
 
 # SVN::Client methods
 #       $ctx->add($path, $recursive, $pool);
@@ -240,6 +240,21 @@ sub wait_for_existence {
     }
 }
 
+sub svn_version {
+    my $self = shift;
+    if (!defined $self->{_svn_version}) {
+	my $fh = IO::File->new("$self->{svn_binary} --version|")
+	    or die "s4: %Error: cannot get $self->{svn_binary} --version\n";
+	while (defined(my $line=$fh->getline)) {
+	    if ($line =~ /svn, version ([0-9]+\.[0-9]+)/) {
+		return ($self->{_svn_version} = $1);
+	    }
+	}
+	die "s4: %Error: cannot get $self->{svn_binary} --version\n";
+    }
+    return $self->{_svn_version};
+}
+
 # call system function, and gripe if it returns nonzero exit status.
 sub run {
     my $self = shift;
@@ -275,12 +290,6 @@ sub run_s4 {
     $self->run (@list);
 }
 
-sub run_svn {
-    my $self = shift;
-    my @list = (split(/\s+/,$self->{svn_binary}), @_);
-    $self->run (@list);
-}
-
 sub hide_all_output {
     my $self = shift;
     if ($self->debug) {
@@ -361,14 +370,13 @@ sub file_url {
     DEBUG "absolute filename = $filename\n" if $self->debug;
     $self->open();
     return undef if $filename =~ m!\.old($|/)!;
-    $self->hide_all_output();
     my $url;
     my $error = 1;
     eval {
+	local $SVN::Error::handler = undef;
 	$url = $self->client->url_from_path($filename, $self->pool);
 	$error = 0;
     };
-    $self->restore_all_output();
     if ($params{assert_exists} && $error) {
         die "s4: %Error: file_url: could not find url for path $filename";
     }
@@ -386,15 +394,18 @@ sub file_root {
 	DEBUG "absolute filename = $filename\n" if $self->debug;
 	$self->open();
 	my $root;
-	$self->hide_all_output();
-	$self->client_reopen();
-	$self->client->info($filename, undef,
-			    $self->is_file_local(filename=>$filename)?undef:'HEAD',
-			    sub {
-				my ($file, $info, $pool) = @_;
-				$root = $info->repos_root_URL;
-			    }, 0);
-	$self->restore_all_output();
+	{
+	    $self->client_reopen();
+	    local $SVN::Error::handler = sub {
+		DEBUG "suppressed-error: ".$_[0]->message."\n" if $self->debug;
+	    };
+	    $self->client->info($filename, undef,
+				$self->is_file_local(filename=>$filename)?undef:'HEAD',
+				sub {
+				    my ($file, $info, $pool) = @_;
+				    $root = $info->repos_root_URL;
+				}, 0);
+	}
 	$root or die "s4: %Error: No SVN root found for $filename\n";
 	DEBUG "\tfile_root $params{filename} -> $root\n" if $self->debug;
 	$self->{_root} = $root;
@@ -453,16 +464,20 @@ sub is_file_in_repo {
 	return 1;
     }
     DEBUG "is_file_in_repo with rev='$params{revision}' url='$url'\n" if $self->debug;
-    $self->hide_all_output();
     my $exists = 0;
     eval {
-	# ."" needed to make sure stringification occurs, as SWIG won't do so
 	$self->client_reopen();
+	my $errored;
+	local $SVN::Error::handler = sub {
+	    DEBUG "suppressed-error: ".$_[0]->message."\n" if $self->debug;
+	    $errored = 1;
+	};
+	# ."" needed to make sure stringification occurs, as SWIG won't do so
 	my $proplist = $self->client->proplist($url, $params{revision}.'', 0);
+
 	DEBUG "proplist returned, so the url must have existed\n" if $self->debug;
-	$exists = 1;
+	$exists = 1 if !$errored;
     };
-    $self->restore_all_output();
     $self->{_file_in_repo}{$params{revision}}{$url} = $exists;
     return $exists;
 }
@@ -610,7 +625,25 @@ sub dir_top_svn {
 sub dir_uses_svn {
     my $self = shift;
     my $path = shift;
-    $self->{_dir_uses_svn_cache}{$path} ||= (-d "$path/.svn") ? 1:0;
+    # Can't simply recurse up for a .svn as we sometimes do create .svn under .svn for
+    # example in regressions, and to test S4 itself (as the S4 program is under .svn and test_dir is not)
+    if (defined $self->{_dir_uses_svn_cache}{$path}) {
+    } elsif (-e "$path/.svn") {  # Short-circuit
+	$self->{_dir_uses_svn_cache}{$path} = 1;
+    } else {
+	{
+	    local $SVN::Error::handler = undef;
+	    my $r = 0;
+	    my $abspath = $self->abs_filename($path);  # Required for <= svn1.6
+	    $self->client->status($abspath, undef, sub {
+		my ($path,$wc_status2) = @_;
+		#print "URL ",$wc_status->url(),"\n";
+		if ($wc_status2->entry()) { $r=1; }
+				  },
+				  0, 1, 0, 0);
+	    $self->{_dir_uses_svn_cache}{$path} = $r;
+	}
+    }
     return $self->{_dir_uses_svn_cache}{$path};
 }
 
@@ -622,7 +655,7 @@ sub dir_uses_viewspec {
     my $viewspec = "$abspath/$self->{viewspec_file}";
 
     # Ignore Viewspec's burried under other (possible) viewspecs
-    my $parent_is_svn = (-d "$abspath/../.svn");
+    my $parent_is_svn = $self->dir_uses_svn("$abspath/..");
     DEBUG "  Note this tree is under another svn tree ($abspath/../.svn)\n" if $parent_is_svn && $self->debug;
     return (!$parent_is_svn && -f $viewspec);
 }
@@ -718,7 +751,7 @@ Create a new SVN::S4 object.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2015 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2016 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
