@@ -15,7 +15,7 @@ use vars qw($AUTOLOAD);
 
 use SVN::S4::Path;
 
-our $VERSION = '1.056';
+our $VERSION = '1.060';
 
 # Basenames we should ignore, because they contain large files of no relevance
 our %_SkipBasenames = (
@@ -95,7 +95,7 @@ sub _fixprops_recurse {
     if (-d $filename) {
 	my $dir = $filename;
 	DEBUG "In $dir\n" if $self->debug;
-	if (!-r "$dir/.svn") {
+	if (!$self->dir_uses_svn($dir)) {
 	    # silently ignore a non a subversion directory
 	} else {
 	    if ($param->{ignores}) {
@@ -285,7 +285,7 @@ keywords that need repair.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2005-2015 by Wilson Snyder.  This package is free software; you
+Copyright 2005-2016 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
