@@ -13,7 +13,7 @@ use Data::Dumper;
 ######################################################################
 #### Configuration Section
 
-our $VERSION = '1.056';
+our $VERSION = '1.060';
 
 our %_Aliases =
     (
@@ -74,6 +74,7 @@ our %_Args =
 	       .' [--depth ARG]'		# 1.6
 	       .' [--force]'
 	       .' [--no-auto-props]'
+	       .' [--no-ignore]'		# 1.8
 	       .' [--parents]'			# 1.6
 	       .' [--targets FILENAME]'
 	       .' [-N|--non-recursive]'
@@ -174,6 +175,8 @@ our %_Args =
 	       .' [--editor-cmd ARG]'		# 1.6
 	       .' [--encoding ENC]'
 	       .' [--force-log]'
+	       .' [--include-externals]'	# 1.8
+	       .' [--keep-changelists]'		# 1.8
 	       .' [--keep-changelist ARG]'	# 1.6
 	       .' [--no-unlock]'
 	       .' [--non-interactive]'
@@ -244,11 +247,18 @@ our %_Args =
 	       .' [--diff-u|-u]'	# 1.4
 	       .' [--diff-w|-w]'	# 1.4
 	       .' [--force]'		# 1.6
+	       .' [--git]'		# 1.7
 	       .' [--ignore-eol-style]'	# 1.4
+	       .' [--ignore-properties]'	# 1.8
+	       .' [--internal-diff]'	# 1.8
 	       .' [--new NEWPATH@NEWPATHREV]'	#PATH[@REV]
+	       .' [--no-diff-added]'	# 1.8
 	       .' [--no-diff-deleted]'
 	       .' [--notice-ancestry]'
 	       .' [--old OLDPATH@OLDPATHREV]'	#PATH[@REV]
+	       .' [--patch-compatible]'	# 1.8
+	       .' [--properties-only]'	# 1.8
+	       .' [--show-copies-as-adds]'	# 1.7
 	       .' [--summarize]'	# 1.4
 	       .' [--xml]'		# 1.6
 	       .' [-N|--non-recursive]'
@@ -269,8 +279,9 @@ our %_Args =
 	       .' [--depth ARG]'		# 1.6
 	       .' [--force]'
 	       .' [--ignore-externals]'		# 1.4
+	       .' [--ignore-keywords]'		# 1.8
 	       .' [--native-eol ARG]'
-	       .' [--non-recursive]'
+	       .' [-N|--non-recursive]'
 	       .' [-q|--quiet]'
 	       .' [-r|--revision REV]'
 	       #
@@ -335,6 +346,7 @@ our %_Args =
   'list'	=> {
       args => (''
 	       .' [--depth ARG]'		# 1.6
+	       .' [--include-externals]'	# 1.8
 	       .' [--incremental]'
 	       .' [--xml]'
 	       .' [-R|--recursive]'
@@ -352,6 +364,7 @@ our %_Args =
   'lock'	=> {
       args => (''
 	       .' [--encoding ENC]'
+	       .' [--force]'			# 1.8
 	       .' [--force-log]'
 	       .' [--targets FILENAME]'
 	       .' [-F|--file FILE]'
@@ -368,13 +381,19 @@ our %_Args =
 	       .' PATH...')},
   'log'		=> {
       args => (''
+	       .' [--depth ARG]'		# 1.8
+	       .' [--diff-cmd ARG]'		# 1.8
+	       .' [--diff]'			# 1.8
 	       .' [--incremental]'
+	       .' [--internal-diff]'		# 1.8
 	       .' [--limit NUM]'
+	       .' [--search ARG]'		# 1.8
+	       .' [--search-and ARG]'		# 1.8
 	       .' [--stop-on-copy]'
+	       .' [--targets FILENAME]'
 	       .' [--with-all-revprops]'	# 1.6
 	       .' [--with-no-revprops]'		# 1.6
 	       .' [--with-revprop ARG]'		# 1.6
-	       .' [--targets FILENAME]'
 	       .' [--xml]'
 	       .' [-c|--change ARG]'		# 1.6
 	       .' [-g|--use-merge-history]'
@@ -382,6 +401,7 @@ our %_Args =
 	       .' [-q|--quiet]'
 	       .' [-r|--revision REV]'
 	       .' [-v|--verbose]'
+	       .' [-x|--extensions ARG]'	# 1.8
 	       #
 	       .' [--username USER]'
 	       .' [--password PASS]'
@@ -396,6 +416,7 @@ our %_Args =
       args => (''#'merge        PATHORURL1[@N]  PATHORURL2[@M]  [WCPATH]'
 	       #'merge -r N:M SOURCE[@REV]                    [WCPATH]'
 	       .' [--accept ARG]'		# 1.6
+	       .' [--allow-mixed-revisions]'	# 1.8
 	       .' [--depth ARG]'		# 1.6
 	       .' [--diff3-cmd CMD]'
 	       .' [--dry-run]'
@@ -407,6 +428,7 @@ our %_Args =
 	       .' [-c|--change REV]'		# 1.4
 	       .' [-q|--quiet]'
 	       .' [-r|--revision REV]'
+	       .' [-v|--verbose]'		# 1.8
 	       .' [-x|--extensions ARGS]'	# 1.4
 	       #
 	       .' [--username USER]'
@@ -419,8 +441,10 @@ our %_Args =
 	       .' PATHORURL@PATHORURLREV...')},
   'mergeinfo'	=> {
       args => (''#mergeinfo SOURCE[@REV] [TARGET[@REV]]
+	       .' [--depth ARG]'		# 1.8
 	       .' [--show-revs ARG]'		# 1.6
 	       .' [-r|--revision ARG]'		# 1.6
+	       .' [-R|--recursive]'		# 1.8
 	       #
 	       .' [--username USER]'
 	       .' [--password PASS]'
@@ -451,6 +475,7 @@ our %_Args =
 	       .' PATHORURL...')},
   'move'	=> {
       args => (''
+	       .' [--allow-mixed-revisions]'	# 1.8
 	       .' [--editor-cmd EDITOR]'
 	       .' [--encoding ENC]'
 	       .' [--force-log]'
@@ -470,6 +495,14 @@ our %_Args =
 	       .' [--config-dir DIR]'
 	       .' [--config-option ARG]'	# 1.6
 	       .' SRC DST')},
+  'patch'	=> {				# 1.7
+      args => (''
+	       .' [-q|--quiet]'
+	       .' [--dry-run]'
+	       .' [--strip ARG]'
+	       .' [--reverse-diff]'
+	       .' [--ignore-whitespace]'
+	       .' PATCHFILE [WCPATH]')},
   'propdel'	=> {
       args => (''#'propdel PROPNAME [PATH...]'
 	       #'propdel PROPNAME --revprop -r REV [URL]'
@@ -515,6 +548,7 @@ our %_Args =
 	       .' [--changelist ARG]'
 	       .' [--depth ARG]'		# 1.6
 	       .' [--revprop]'
+	       .' [--show-inherited-props]'	# 1.8
 	       .' [--strict]'
 	       .' [--xml]'
 	       .' [-R|--recursive]'
@@ -535,6 +569,7 @@ our %_Args =
 	       .' [--changelist ARG]'
 	       .' [--depth ARG]'		# 1.6
 	       .' [--revprop]'
+	       .' [--show-inherited-props]'	# 1.8
 	       .' [--xml]'
 	       .' [-R|--recursive]'
 	       .' [-q|--quiet]'
@@ -571,6 +606,20 @@ our %_Args =
 	       .' [--config-dir DIR]'
 	       .' [--config-option ARG]'	# 1.6
 	       .' PROPNAME [PATHORURL...]')},
+  'relocate'	=> {				# 1.7
+      args => (''
+	       #'relocate FROM-PREFIX TO-PREFIX [PATH...]
+	       #'relocate TO-URL [PATH]
+	       .' [--ignore-externals]'
+	       #
+	       .' [--username USER]'
+	       .' [--password PASS]'
+	       .' [--no-auth-cache]'
+	       .' [--non-interactive]'
+	       .' [--trust-server-cert]'
+	       .' [--config-dir DIR]'
+	       .' [--config-option ARG]'
+	       .' TOFROM [PATHORURL...]')},
   'resolve'	=> {
       args => (''
 	       .' [--accept ARG]'
@@ -633,6 +682,7 @@ our %_Args =
 	       .' [--depth ARG]'
 	       .' [--diff3-cmd CMD]'
 	       .' [--force]'
+	       .' [--ignore-ancestry]'		# 1.7
 	       .' [--ignore-externals]'
 	       .' [--relocate]'   # technically [--relocate FROM TO] but parser below doesn't support
 	       .' [--set-depth ARG]'
@@ -673,6 +723,7 @@ our %_Args =
 	       .' [--editor-cmd EDITOR]'
 	       .' [--force]'
 	       .' [--ignore-externals]'
+	       .' [--parents]'			# 1.8
 	       .' [--set-depth ARG]'		# 1.6
 	       .' [-N|--non-recursive]'
 	       .' [-q|--quiet]'
@@ -686,6 +737,9 @@ our %_Args =
 	       .' [--config-dir DIR]'
 	       .' [--config-option ARG]'	# 1.6
 	       .' [PATH...]')},
+  'upgrade'	=> {
+      args => (''
+	       .' [-q|--quiet]')},		# 1.8
   #####
   # Commands added in S4
   'cat-or-mods' => {
@@ -1168,7 +1222,7 @@ Return the option list, with the specified matching argument removed.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2015 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2016 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
