@@ -17,7 +17,7 @@ use SVN::S4;
 use SVN::S4::Debug qw (DEBUG is_debug);
 use SVN::S4::Path;
 
-our $VERSION = '1.056';
+our $VERSION = '1.060';
 our $Info = 1;
 
 
@@ -158,11 +158,11 @@ sub checkout {
     my $co_under_co = $self->config_get_bool('s4', 'co-under-co');
     my $no_co_under_co = (!defined $co_under_co ? 0 : !$co_under_co);
     $no_co_under_co = ($no_co_under_co || $found_viewspec || -e "$params{path}/$self->{viewspec_file}");
-    if (-e "$params{path}/.svn" && $no_co_under_co) {
+    if ($self->dir_uses_svn($params{path}) && $no_co_under_co) {
 	die "s4: %Error: Stubbornly refusing to checkout on top of existing checkout; you probably wanted 'update'\n";
     }
     my $parent = $self->_parent_of_path($params{path});
-    if (-e "$parent/.svn" && $found_viewspec) {
+    if ($self->dir_uses_svn($parent) && $found_viewspec) {
 	die "s4: %Error: Stubbornly refusing to checkout path with viewspec, under a parent SVN directory\n";
 	# Edit the viewspec instead.  Otherwise when they update we'll ignore the viewspec and get confused.
     }
