@@ -8,6 +8,8 @@ use strict;
 use Carp;
 use IO::Dir;
 use IO::File;
+use DBI;
+use DBD::SQLite;
 use Cwd;
 use Digest::MD5;
 use vars qw($AUTOLOAD);
@@ -16,7 +18,7 @@ use SVN::S4;
 use SVN::S4::Debug qw (DEBUG is_debug);
 use SVN::S4::Path;
 
-our $VERSION = '1.056';
+our $VERSION = '1.060';
 our $Info = 1;
 
 
@@ -387,7 +389,8 @@ sub apply_viewspec {
 		if ($uuid ne $base_uuid) {
 		    die "s4: %Error: URL $action->{url} is in a different repository! What you need is an SVN external, which viewspecs presently do not support.";
 		}
-		my $cmd = "$self->{svn_binary} switch $action->{url} $cleandir -r$rev";
+		my $ign = ($self->svn_version >= 1.7) ? "--ignore-ancestry" : "";
+		my $cmd = "$self->{svn_binary} switch $ign $action->{url} $cleandir -r$rev";
 		$cmd .= ' --quiet' if $self->quiet;
 		if (!$self->quiet) {
 		    print "s4: Switching $reldir";
@@ -415,6 +418,7 @@ sub _undo_switches {
     my $self = shift;
     my %params = (#basepath=>,
                   @_);
+    DEBUG "s4: undo_switches basepath = $params{basepath}\n" if $self->debug;
     # Find the list of switchpoints that S4 created
     # If it can't be found, just return.
     if (!$self->{prev_state}) {
@@ -467,7 +471,8 @@ sub _remove_switchpoint {
     }
     my $url = $self->file_url(filename=>$path);
     my $voidurl = $self->void_url(url => $url);
-    my $cmd = qq{$self->{svn_binary} switch --quiet $voidurl $path};
+    my $ign = ($self->svn_version >= 1.7) ? "--ignore-ancestry" : "";
+    my $cmd = qq{$self->{svn_binary} switch --quiet $ign $voidurl $path};
     $self->run($cmd);
     # Is it totally empty?
     my $status_items = 0;
@@ -485,14 +490,21 @@ sub _remove_switchpoint {
      # For a totally empty directory, status returns just one thing: the
      # directory itself.
      if ($status_items==1) {
-	DEBUG "s4: Removing $path from working area\n" if $self->debug;
+	 DEBUG "s4: Removing $path from working area\n" if $self->debug;
 	 # Do it gently to reduce chance of wiping out. Only use the big hammer on
 	 # the .svn directory itself.  This may "fail" because of leftover .nfs crap;
 	 # then what's the right answer?
-         $self->run ("rm -rf $path/.svn");
-         $self->run ("rmdir $path");
+         $self->run ("/bin/rm -rf $path/.svn");
+         $self->run ("/bin/rmdir $path");
 	 DEBUG "s4: running $self->{svn_binary} update -r $self->{revision} on $abspath\n" if $self->debug;
-	 $self->run ("$self->{svn_binary} up -N --revision $self->{revision} $path");
+	 my $fmt = $self->_wc_format($params{basepath});
+	 if ($fmt == 4 || ($fmt >= 8 && $fmt <= 10)) {
+	     $self->run ("$self->{svn_binary} up -N --revision $self->{revision} $path");
+	 } elsif ($fmt == 12) {
+	     $self->_wc_db_del($params{basepath}, $params{dir});
+	 } else {
+	     die "s4: %Error: remove_switchpoint: s4 does not know how to remove switchpoints in working copy format " . (0+$fmt);
+	 }
      } else {
          print "s4: Ignoring obsolete switchpoint $path because there are still files under it.\n";
          print "s4: If you remove those files, you can remove the switchpoint manually, by deleting\n";
@@ -517,7 +529,8 @@ sub _create_switchpoint_hierarchical {
 		# really needed.  And the value gets cached, so the
 		# 2nd, 3rd, etc. call takes no time.
 		my $voidurl = $self->void_url(url => $self->file_url(filename=>$basedir));
-		$self->run ("$self->{svn_binary} switch --quiet $voidurl $basedir/$dirpart");
+		my $ign = ($self->svn_version >= 1.7) ? "--ignore-ancestry" : "";
+		$self->run ("$self->{svn_binary} switch $ign --quiet $voidurl $basedir/$dirpart");
 		$self->wait_for_existence (path=>"$basedir/$dirpart");
 		push @{$self->{viewspec_managed_switches}},
 		    $self->clean_filename("$basedir/$dirpart");
@@ -539,61 +552,57 @@ sub _create_switchpoint {
     # it to anything you want.  Strange but useful.
     # This hack is specific to the working copy format, so check that the working
     # copy format is one that I recognize.
-    my $format_file = "$basedir/.svn/format";
-    my $entries_file = "$basedir/.svn/entries";
-    my $fmt;
-    {
-	my $fp = (IO::File->new("<$format_file")
-		  || IO::File->new("<$entries_file"));
-	$fp or die "s4: %Error: $! opening $format_file or $entries_file";
-	$fmt = $fp->getline;
-	chomp $fmt;
-    }
-    if (!($fmt == 4 || ($fmt >= 8 && $fmt <= 10))) {
-	die "s4: %Error: create_switchpoint: I only know how to create switchpoints in working copy format=4 or format=8. But this working copy is format " . (0+$fmt);
-    }
-
-    my $newfile = "$basedir/.svn/s4_tmp_$$";
-    unlink(glob("$basedir/.svn/s4_tmp_*"));
-    open (IN, $entries_file) or die "s4: %Error: $! opening $entries_file";
     die "s4: %Error: can't make a switchpoint with a quote in it!" if $targetdir =~ /\"/;
-    my @out;
-    if ($fmt == 4) {
-	while (<IN>) {
-	    if (/name="$targetdir"/) {
-		die "s4: %Error: create_switchpoint: an entry called '$targetdir' already exists in .svn/entries";
+    my $fmt = $self->_wc_format($basedir);
+    if ($fmt == 4 || ($fmt >= 8 && $fmt <= 10)) {
+	my $entries_file = "$basedir/.svn/entries";
+	my $newfile = "$basedir/.svn/s4_tmp_$$";
+	unlink(glob("$basedir/.svn/s4_tmp_*"));
+	open (IN, $entries_file) or die "s4: %Error: $! opening $entries_file";
+	my @out;
+	if ($fmt == 4) {
+	    while (<IN>) {
+		if (/name="$targetdir"/) {
+		    die "s4: %Error: create_switchpoint: an entry called '$targetdir' already exists in .svn/entries";
+		}
+		if (/<\/wc-entries>/) {
+		    # Fmt=4: Just before the </wc-entries> line, add this entry
+		    push @out, qq{<entry name="$targetdir" kind="dir"/> \n};
+		}
+		push @out, $_;
 	    }
-	    if (/<\/wc-entries>/) {
-		# Fmt=4: Just before the </wc-entries> line, add this entry
-		push @out, qq{<entry name="$targetdir" kind="dir"/> \n};
-	    }
-	    push @out, $_;
 	}
-    }
-    elsif ($fmt >= 8) {
-	# See subversion sources: subversion/libsvn_wc/entries.c
-	# Entries terminated by \f at next entry, then
-	#   kind, revision, url path, repo_root, schedule, timestamp, checksum,
-	#   cmt_date, cmt_rev, cmt_author, has_props, has_props_mod,
-	#   cachable_done, present_props,
-	#   prejfile, conflict_old, conflict_new, conflict_wrk,
-	#   copied, copyfrom_url, copyfrom_rev, deleted, absent, incomplete
-	#   uuid, lock_token, lock_owner, lock_comment, lock_creation_date,
-	#   changelist, keep_local, size, depth, tree_conflict_data,
-	#   external information
-	while (<IN>) {
-	    if (/^$targetdir/) {
-		die "s4: %Error: create_switchpoint: an entry called '$targetdir' already exists in .svn/entries";
+	elsif ($fmt >= 8) {
+	    # See subversion sources: subversion/libsvn_wc/entries.c
+	    # Entries terminated by \f at next entry, then
+	    #   kind, revision, url path, repo_root, schedule, timestamp, checksum,
+	    #   cmt_date, cmt_rev, cmt_author, has_props, has_props_mod,
+	    #   cachable_done, present_props,
+	    #   prejfile, conflict_old, conflict_new, conflict_wrk,
+	    #   copied, copyfrom_url, copyfrom_rev, deleted, absent, incomplete
+	    #   uuid, lock_token, lock_owner, lock_comment, lock_creation_date,
+	    #   changelist, keep_local, size, depth, tree_conflict_data,
+	    #   external information
+	    while (<IN>) {
+		if (/^$targetdir/) {
+		    die "s4: %Error: create_switchpoint: an entry called '$targetdir' already exists in .svn/entries";
+		}
+		push @out, $_;
 	    }
-	    push @out, $_;
+	    # Right at the end, add new entry.
+	    push @out, "$targetdir\ndir\n" . chr(12) . "\n";
 	}
-	# Right at the end, add new entry.
-	push @out, "$targetdir\ndir\n" . chr(12) . "\n";
+	open (OUT, ">$newfile") or die "s4: %Error: $! opening $newfile";
+	print OUT join('',@out);
+	close OUT;
+	rename($newfile, $entries_file) or die "s4: Internal-%Error: $! on 'mv $newfile $entries_file',";
+    }
+    elsif ($fmt == 12) {
+	$self->_wc_db_add($basedir, $targetdir);
+    }
+    else {
+	die "s4: %Error: create_switchpoint: s4 does not know how to create switchpoints in working copy format " . (0+$fmt);
     }
-    open (OUT, ">$newfile") or die "s4: %Error: $! opening $newfile";
-    print OUT join('',@out);
-    close OUT;
-    rename($newfile, $entries_file) or die "s4: Internal-%Error: $! on 'mv $newfile $entries_file',";
 }
 
 sub viewspec_urls {
@@ -607,6 +616,97 @@ sub viewspec_urls {
     return sort keys %urls;
 }
 
+sub _wc_format {
+    my $self = shift;
+    my ($basedir) = @_;
+    my $format_file = "$basedir/.svn/format";
+    my $entries_file = "$basedir/.svn/entries";
+    my $fp = (IO::File->new("<$format_file")
+	      || IO::File->new("<$entries_file"));
+    $fp or die "s4: %Error: $! opening $format_file or $entries_file";
+    my $fmt = $fp->getline;
+    chomp $fmt;
+    return $fmt;
+}
+
+sub _wc_db_connect {
+    my $self = shift;
+    my $basedir = shift;
+    my $dbfile = "$basedir/.svn/wc.db";
+    my $dbh = DBI->connect('dbi:SQLite:dbname='.$dbfile,'','',{AutoCommit=>1,RaiseError=>1,PrintError=>1});
+    $dbh or die "s4: %Error: $! opening SQLite $dbfile";
+    # sqlite3 .svn/wc.db
+    # .dump
+    return $dbh;
+}
+
+sub _wc_db_add {
+    my $self = shift;
+    my $basedir = shift;
+    my $targetdir = shift;
+    # Internal, edit .wc.db file to add specified target directory
+    my $dbh = $self->_wc_db_connect($basedir);
+    {
+	my $sql = "SELECT local_relpath FROM nodes WHERE local_relpath = ?";
+	my $sth = $dbh->prepare($sql);
+	my $e = $sth->execute($targetdir);
+	my $fa = $sth->fetchall_arrayref;
+	(!$fa->[0]) or die "s4: %Error: create_switchpoint: an entry called '$targetdir' already exists in $basedir,";
+    }
+    my $max_rev;
+    {
+	my $sql = "SELECT MAX(revision) FROM nodes";
+	my $sth = $dbh->prepare($sql);
+	my $e = $sth->execute();
+	my $fa = $sth->fetchall_arrayref;
+	$max_rev = $fa->[0][0] or die "s4: %Error: create_switchpoint: no maximum revision found in $basedir,";
+    }
+    my $updir = "";
+    $updir = $1 if $targetdir =~ m!^(.*)/([^/]+)$!;
+    {
+	DEBUG "s4: sql: insert node '$targetdir' under '$updir' rev '$max_rev'\n" if $self->debug;
+	my $sql = "INSERT INTO nodes VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
+	my $sth = $dbh->prepare($sql);
+	my $e = $sth->execute(
+	    1,			# wc_id  INTEGER NOT NULL REFERENCES WCROOT (id),
+	    $targetdir,		# local_relpath  TEXT NOT NULL,
+	    0,			# op_depth INTEGER NOT NULL,
+	    $updir,		# parent_relpath  TEXT,
+	    1,			# repos_id  INTEGER REFERENCES REPOSITORY (id),
+	    'void',		# repos_path  TEXT,
+	    $max_rev,		# revision  INTEGER,
+	    'normal',		# presence  TEXT NOT NULL,
+	    undef,		# moved_here  INTEGER,
+	    undef,		# moved_to  TEXT,
+	    'dir',		# kind  TEXT NOT NULL,
+	    '()',		# properties  BLOB,
+	    'infinity',		# depth  TEXT,
+	    undef,		# checksum  TEXT REFERENCES PRISTINE (checksum),
+	    undef,		# symlink_target  TEXT,
+	    1,			# changed_revision  INTEGER,
+	    time(),		# changed_date      INTEGER,
+	    'author',		# changed_author    TEXT,
+	    undef,		# translated_size  INTEGER,
+	    undef,		# last_mod_time  INTEGER,
+	    undef,		# dav_cache  BLOB,
+	    undef,		# file_external  INTEGER,
+	    undef);		# inherited_props  BLOB
+    }
+}
+
+sub _wc_db_del {
+    my $self = shift;
+    my $basedir = shift;
+    my $targetdir = shift;
+    # Internal, edit .wc.db file to add specified target directory
+    my $dbh = $self->_wc_db_connect($basedir);
+    {
+	my $sql = "DELETE FROM nodes WHERE local_relpath = ?";
+	my $sth = $dbh->prepare($sql);
+	my $e = $sth->execute($targetdir);
+    }
+}
+
 ######################################################################
 ### Package return
 package SVN::S4::ViewSpec;
