@@ -1,6 +1,6 @@
 # DESCRIPTION: Perl ExtUtils: Common routines required by package tests
 #
-# Copyright 2002-2015 by Wilson Snyder.  This program is free software;
+# Copyright 2002-2016 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -20,6 +20,8 @@ $REPO = "file://localhost$REPOFN";
 
 mkdir 'test_dir',0777;
 
+$ENV{LANG} = "en_US";  # Otherwise expect's will blow up
+
 if (!$ENV{HARNESS_ACTIVE}) {
     use lib '.';
     use lib '..';
@@ -113,4 +115,19 @@ sub touch ($$) {
     $fh->close;
 }
 
+our $_Svn_Version;
+sub svn_version {
+    if (!defined $_Svn_Version) {
+	my $fh = IO::File->new("svn --version|")
+	    or die "%Error: cannot get $self->{svn_binary} --version\n";
+	while (defined(my $line=$fh->getline)) {
+	    if ($line =~ /svn, version ([0-9]+\.[0-9]+)/) {
+		return ($_Svn_Version = $1);
+	    }
+	}
+	die "%Error: cannot get svn --version\n";
+    }
+    return $_Svn_Version;
+}
+
 1;
